@@ -44,7 +44,7 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 110101
+#define ECL_VERSION_NUMBER 130501
 
 /*
  * FEATURES LINKED IN
@@ -79,7 +79,7 @@
 #   define GC_THREADS		/* For >= 7.2 */
 # endif
 # define ECL_DYNAMIC_VV
-# include "gc/gc.h"
+# include "gc.h"
 /* GC >= 7.2 defines these macros to intercept thread functions, but
  * in doing so it breaks mingw. */
 # if defined(ECL_MS_WINDOWS_HOST) && defined(_beginthreadex)
@@ -89,6 +89,7 @@
 #  undef _endthreadex
 # endif
 #endif
+#undef ECL_LIBATOMIC_OPS_H
 
 /* Network streams							*/
 #undef TCP
@@ -101,6 +102,8 @@
 
 /* Support for Unicode strings */
 #undef ECL_UNICODE
+/* Link in the Unicode names for all characters (takes ~0.5 Mb)		*/
+#undef ECL_UNICODE_NAMES
 
 /* Allow STREAM operations to work on arbitrary objects			*/
 #undef ECL_CLOS_STREAMS
@@ -153,10 +156,10 @@
 #define ECL_INT_BITS		32
 #define ECL_LONG_BITS		64
 #define FIXNUM_BITS		64
-#define MOST_POSITIVE_FIXNUM	((cl_fixnum)2305843009213693951)
-#define MOST_NEGATIVE_FIXNUM	((cl_fixnum)-2305843009213693952)
-#define MOST_POSITIVE_FIXNUM_VAL 2305843009213693951
-#define MOST_NEGATIVE_FIXNUM_VAL -2305843009213693952
+#define MOST_POSITIVE_FIXNUM	((cl_fixnum)2305843009213693951L)
+#define MOST_NEGATIVE_FIXNUM	((cl_fixnum)-2305843009213693952L)
+#define MOST_POSITIVE_FIXNUM_VAL 2305843009213693951L
+#define MOST_NEGATIVE_FIXNUM_VAL -2305843009213693952L
 
 typedef long int cl_fixnum;
 typedef unsigned long int cl_index;
@@ -165,22 +168,20 @@ typedef unsigned long int cl_hashkey;
 /*
  * The character type
  */
-#ifdef ECL_UNICODE
-#define	CHAR_CODE_LIMIT	1114112	/*  unicode character code limit  */
-#else
-#define	CHAR_CODE_LIMIT	256	/*  unicode character code limit  */
-#endif
+#define	ECL_CHAR_CODE_LIMIT	1114112 /* ASCII or unicode character code limit  */
+typedef int32_t ecl_character;
+typedef unsigned char ecl_base_char;
 
 /*
  * Array limits
  */
-#define	ARANKLIM	64		/*  array rank limit  		*/
+#define	ECL_ARRAY_RANK_LIMIT 64	/*  array rank limit  		*/
 #ifdef GBC_BOEHM
-#define	ADIMLIM		2305843009213693951	/*  array dimension limit	*/
-#define	ATOTLIM		2305843009213693951	/*  array total limit		*/
+#define	ECL_ARRAY_DIMENSION_LIMIT 2305843009213693951L
+#define	ECL_ARRAY_TOTAL_LIMIT 2305843009213693951L
 #else
-#define	ADIMLIM		16*1024*1024	/*  array dimension limit	*/
-#define	ATOTLIM		16*1024*1024	/*  array total limit		*/
+#define	ECL_ARRAY_DIMENSION_LIMIT 16*1024*1024
+#define	ECL_ARRAY_TOTAL_LIMIT 16*1024*1024
 #endif
 
 /*
@@ -189,16 +190,16 @@ typedef unsigned long int cl_hashkey;
  * In general, any of these limits must fit in a "signed int".
  */
 /*	Maximum number of function arguments (arbitrary)		*/
-#define CALL_ARGUMENTS_LIMIT 65536
+#define ECL_CALL_ARGUMENTS_LIMIT 65536
 
 /*	Maximum number of required arguments				*/
-#define LAMBDA_PARAMETERS_LIMIT CALL_ARGUMENTS_LIMIT
+#define ECL_LAMBDA_PARAMETERS_LIMIT ECL_CALL_ARGUMENTS_LIMIT
 
 /*	Numb. of args. which will be passed using the C stack		*/
 /*	See cmplam.lsp if you change this value				*/
-#define C_ARGUMENTS_LIMIT 64
+#define ECL_C_ARGUMENTS_LIMIT 63
 
-/*	Maximum number of output arguments (>= C_ARGUMENTS_LIMIT)	*/
+/*	Maximum number of output arguments (>= ECL_C_ARGUMENTS_LIMIT)	*/
 #define ECL_MULTIPLE_VALUES_LIMIT 64
 
 /* A setjmp that does not save signals					*/
@@ -207,7 +208,7 @@ typedef unsigned long int cl_hashkey;
 
 /*
  * Structure/Instance limits. The index to a slot must fit in the
- * "int" type. We also require ECL_SLOTS_LIMIT <= CALL_ARGUMENTS_LIMIT
+ * "int" type. We also require ECL_SLOTS_LIMIT <= ECL_CALL_ARGUMENTS_LIMIT
  * because constructors typically require as many arguments as slots,
  * or more.
  */
@@ -222,14 +223,21 @@ typedef unsigned long int cl_hashkey;
 /* We can use small, two-words conses, without type information		*/
 #undef ECL_SMALL_CONS
 
+/* Use CMU Common-Lisp's FORMAT routine					*/
+#undef ECL_CMU_FORMAT
+
 /*
  * C macros for inlining, denoting probable code paths and other stuff
  * that makes better code. Most of it is GCC specific.
  */
-#if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
+#if defined(__cplusplus) || \
+    (defined(__GNUC__) &&   \
+    (defined(__GNUC_GNU_INLINE__) || defined(__GNUC_STDC_INLINE__)))
 #define ECL_INLINE inline
+#define ECL_CAN_INLINE 1
 #else
 #define ECL_INLINE
+#define ECL_CAN_INLINE 0
 #endif
 
 #if !defined(__GNUC__)
@@ -283,9 +291,6 @@ typedef unsigned long int cl_hashkey;
 /* Undefine this if you do not want ECL to check for circular lists	*/
 #define ECL_SAFE
 
-/* Use CMU Common-Lisp's FORMAT routine					*/
-#undef ECL_CMU_FORMAT
-
 /* Bytecodes and arguments are 8 and 16 bits large, respectively	*/
 #undef ECL_SMALL_BYTECODES
 
@@ -298,6 +303,11 @@ typedef unsigned long int cl_hashkey;
 /* Activate Boehm-Weiser precise garbage collector			*/
 #undef GBC_BOEHM_PRECISE
 
+/* Weak hash tables need the garbage collector and weak	pointers	*/
+#ifdef GBC_BOEHM
+#define ECL_WEAK_HASH
+#endif
+
 /*
  * SYSTEM FEATURES:
  */
@@ -389,8 +399,6 @@ typedef unsigned long int cl_hashkey;
 #undef HAVE_COPYSIGNL
 /* whether we have sched_yield() that gives priority to other threads	*/
 #undef HAVE_SCHED_YIELD
-/* whether we semaphore.h                                               */
-#undef HAVE_SEMAPHORE_H
 /* whether we have a working sem_init()                                 */
 #undef HAVE_SEM_INIT
 /* whether we have read/write locks                                     */
@@ -399,6 +407,7 @@ typedef unsigned long int cl_hashkey;
 #undef HAVE_UNAME
 #undef HAVE_UNISTD_H
 #undef HAVE_SYS_WAIT_H
+#undef HAVE_SYS_MMAN_H
 /* size of long long            					*/
 #undef ECL_LONG_LONG_BITS
 /* existence of char **environ         					*/
@@ -408,6 +417,7 @@ typedef unsigned long int cl_hashkey;
 #undef HAVE_BACKTRACE
 #undef HAVE_BACKTRACE_SYMBOLS
 #undef HAVE___BUILTIN_RETURN_ADDRESS
+#undef HAVE_SCHED_H
 
 /*
  * we do not manage to get proper signal handling of floating point
@@ -470,7 +480,7 @@ typedef unsigned long int cl_hashkey;
 #  define PATH_SEPARATOR	':'
 #endif
 
-#define ECL_ARCHITECTURE "ALPHA"
+#define ECL_ARCHITECTURE "SPARC64"
 
 #ifdef ECL_AVOID_FPE_H
 # define ecl_detect_fpe()
